@@ -3,23 +3,31 @@ from .._impl import (
     scout_api_ChannelLocator as ChannelLocator,
     scout_api_ClosedWithFurtherActionDispositionState as ClosedWithFurtherActionDispositionState,
     scout_api_ClosedWithIgnoreDispositionState as ClosedWithIgnoreDispositionState,
+    scout_api_Color as Color,
+    scout_api_ColorVisitor as ColorVisitor,
     scout_api_DataSourceRefName as DataSourceRefName,
     scout_api_DispositionState as DispositionState,
     scout_api_DispositionStateVisitor as DispositionStateVisitor,
     scout_api_HexColor as HexColor,
     scout_api_PendingReviewDispositionState as PendingReviewDispositionState,
     scout_api_Priority as Priority,
+    scout_api_Symbol as Symbol,
+    scout_api_SymbolVisitor as SymbolVisitor,
 )
 
 __all__ = [
     'ChannelLocator',
     'ClosedWithFurtherActionDispositionState',
     'ClosedWithIgnoreDispositionState',
+    'Color',
+    'ColorVisitor',
     'DataSourceRefName',
     'DispositionState',
     'DispositionStateVisitor',
     'HexColor',
     'PendingReviewDispositionState',
     'Priority',
+    'Symbol',
+    'SymbolVisitor',
 ]
 
