@@ -139,12 +139,17 @@ from .._impl import (
     scout_compute_api_ExponentialCurve as ExponentialCurve,
     scout_compute_api_ExponentialResultDetails as ExponentialResultDetails,
     scout_compute_api_Fft as Fft,
+    scout_compute_api_FftWindow as FftWindow,
     scout_compute_api_FirstPointMatchingCondition as FirstPointMatchingCondition,
     scout_compute_api_ForwardFillInterpolation as ForwardFillInterpolation,
     scout_compute_api_ForwardFillResampleInterpolationConfiguration as ForwardFillResampleInterpolationConfiguration,
     scout_compute_api_FrequencyDomain as FrequencyDomain,
     scout_compute_api_FrequencyDomainPlot as FrequencyDomainPlot,
     scout_compute_api_FrequencyDomainVisitor as FrequencyDomainVisitor,
+    scout_compute_api_FunctionDerivedSeries as FunctionDerivedSeries,
+    scout_compute_api_FunctionParameterName as FunctionParameterName,
+    scout_compute_api_FunctionParameterValue as FunctionParameterValue,
+    scout_compute_api_FunctionParameterValueVisitor as FunctionParameterValueVisitor,
     scout_compute_api_FunctionReference as FunctionReference,
     scout_compute_api_FunctionVariables as FunctionVariables,
     scout_compute_api_GeoPoint as GeoPoint,
@@ -200,6 +205,8 @@ from .._impl import (
     scout_compute_api_MinSeries as MinSeries,
     scout_compute_api_Minimum as Minimum,
     scout_compute_api_ModuleApplicationDerivedSeries as ModuleApplicationDerivedSeries,
+    scout_compute_api_ModuleVersionReference as ModuleVersionReference,
+    scout_compute_api_ModuleVersionReferenceVisitor as ModuleVersionReferenceVisitor,
     scout_compute_api_NegativeValueConfiguration as NegativeValueConfiguration,
     scout_compute_api_NegativeValueConfigurationVisitor as NegativeValueConfigurationVisitor,
     scout_compute_api_NotRanges as NotRanges,
@@ -246,7 +253,10 @@ from .._impl import (
     scout_compute_api_PeakRanges as PeakRanges,
     scout_compute_api_PeakType as PeakType,
     scout_compute_api_PercentageThreshold as PercentageThreshold,
+    scout_compute_api_Periodogram as Periodogram,
+    scout_compute_api_PeriodogramMethod as PeriodogramMethod,
     scout_compute_api_PersistenceWindowConfiguration as PersistenceWindowConfiguration,
+    scout_compute_api_PinnedModuleVersionReference as PinnedModuleVersionReference,
     scout_compute_api_Point3d as Point3d,
     scout_compute_api_PolynomialCurve as PolynomialCurve,
     scout_compute_api_PolynomialResultDetails as PolynomialResultDetails,
@@ -490,12 +500,17 @@ __all__ = [
     'ExponentialCurve',
     'ExponentialResultDetails',
     'Fft',
+    'FftWindow',
     'FirstPointMatchingCondition',
     'ForwardFillInterpolation',
     'ForwardFillResampleInterpolationConfiguration',
     'FrequencyDomain',
     'FrequencyDomainVisitor',
     'FrequencyDomainPlot',
+    'FunctionDerivedSeries',
+    'FunctionParameterName',
+    'FunctionParameterValue',
+    'FunctionParameterValueVisitor',
     'FunctionReference',
     'FunctionVariables',
     'GeoPoint',
@@ -551,6 +566,8 @@ __all__ = [
     'MinSeries',
     'Minimum',
     'ModuleApplicationDerivedSeries',
+    'ModuleVersionReference',
+    'ModuleVersionReferenceVisitor',
     'NegativeValueConfiguration',
     'NegativeValueConfigurationVisitor',
     'NotRanges',
@@ -597,7 +614,10 @@ __all__ = [
     'PeakRanges',
     'PeakType',
     'PercentageThreshold',
+    'Periodogram',
+    'PeriodogramMethod',
     'PersistenceWindowConfiguration',
+    'PinnedModuleVersionReference',
     'Point3d',
     'PolynomialCurve',
     'PolynomialResultDetails',
