@@ -95,6 +95,7 @@ from .._impl import (
     scout_compute_resolved_api_OffsetSeriesNode as OffsetSeriesNode,
     scout_compute_resolved_api_OnChangeRangesNode as OnChangeRangesNode,
     scout_compute_resolved_api_PercentageThreshold as PercentageThreshold,
+    scout_compute_resolved_api_PeriodogramNode as PeriodogramNode,
     scout_compute_resolved_api_PersistenceWindowConfiguration as PersistenceWindowConfiguration,
     scout_compute_resolved_api_PolynomialCurve as PolynomialCurve,
     scout_compute_resolved_api_PowerCurve as PowerCurve,
@@ -254,6 +255,7 @@ __all__ = [
     'OffsetSeriesNode',
     'OnChangeRangesNode',
     'PercentageThreshold',
+    'PeriodogramNode',
     'PersistenceWindowConfiguration',
     'PolynomialCurve',
     'PowerCurve',
